@@ -8,10 +8,9 @@
 // following an empty import.
 
 package a
-import""  // ERROR "import path is empty"
-var?      // ERROR "invalid declaration"
+var?      // ERROR "invalid character U\+003F '\?'|invalid character 0x3f in input file"
 
-var x int // ERROR "unexpected var"
+var x int // ERROR "unexpected keyword var|expected identifier|expected type"
 
 func main() {
 }
